==> appier_flutter-2.0.0-dev.3.tar.gz: android/src/main/kotlin/com/appier/appier_flutter/MethodCallHandlerImpl.kt <==
package com.appier.appier_flutter

import androidx.annotation.NonNull
import io.flutter.plugin.common.BinaryMessenger
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel

class MethodCallHandlerImpl(private val appierFlutter: AppierFlutter) : MethodChannel.MethodCallHandler {

  /**
   * The MethodChannel that will the communication between Flutter and native Android
   *
   * This local reference serves to register the plugin with the Flutter Engine and unregister it
   * when the Flutter Engine is detached from the Activity
   */
  private var channel: MethodChannel? = null

  /**
   * Registers this instance as a method call handler on the given `messenger`.
   *
   * Stops any previously started and unstopped calls.
   * This should be cleaned with [.stopListening] once the messenger is disposed of.
   */
  fun startListening(messenger: BinaryMessenger) {
    channel = MethodChannel(messenger, "appier_flutter")
    channel?.setMethodCallHandler(this)
  }

  /**
   * Clears this instance from listening to method calls.
   *
   * Does nothing if [.startListening] hasn't been called, or if we're already stopped.
   */
  fun stopListening() {
    channel?.setMethodCallHandler(null)
    channel = null
  }

  @Suppress("UNCHECKED_CAST")
  override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: MethodChannel.Result) {
    val arguments = call.arguments as? HashMap<String , Any?>
    if (arguments == null) {
      result.error("ILLEGAL_ARGUMENT", "${call.method}: arguments should be a hashmap", null)
      return
    }
    when (call.method) {
      "configure" -> appierFlutter.configure(arguments, result)
      "renewUserId" -> appierFlutter.renewUserId(arguments, result)
      "setUniversalLinkDomains" -> appierFlutter.setUniversalLinkDomains(result)
      "logEvent" -> appierFlutter.logEvent(arguments, result)
      "flush" -> appierFlutter.flush(arguments, result)
      "setUserId" -> appierFlutter.setUserId(arguments, result)
      "setName" -> appierFlutter.setName(arguments, result)
      "setFirstName" -> appierFlutter.setFirstName(arguments, result)
      "setLastName" -> appierFlutter.setLastName(arguments, result)
      "setCity" -> appierFlutter.setCity(arguments, result)
      "setEmail" -> appierFlutter.setEmail(arguments, result)
      "setPhoneNumber" -> appierFlutter.setPhoneNumber(arguments, result)
      "setDayOfBirth" -> appierFlutter.setDayOfBirth(arguments, result)
      "setMonthOfBirth" -> appierFlutter.setMonthOfBirth(arguments, result)
      "setYearOfBirth" -> appierFlutter.setYearOfBirth(arguments, result)
      "setCustomKey" -> appierFlutter.setCustomKey(arguments, result)
      "setAttributionWindow" -> appierFlutter.setAttributionWindow(arguments, result)
      "setClickAttributionWindow" -> appierFlutter.setClickAttributionWindow(arguments, result)
      "getRecommendation" -> appierFlutter.getRecommendation(arguments, result)
      "logRecommendationClicked" -> appierFlutter.logRecommendationClicked(arguments, result)
      "handleRemoteMessage" -> appierFlutter.handleRemoteMessage(arguments, result)
      "hideInAppCampaigns" -> appierFlutter.hideInAppCampaigns(arguments, result)
      else -> result.notImplemented()
    }
  }
}

==> appier_flutter-2.3.0.tar.gz: android/src/main/kotlin/com/appier/appier_flutter/MethodCallHandlerImpl.kt <==
package com.appier.appier_flutter

import androidx.annotation.NonNull
import io.flutter.plugin.common.BinaryMessenger
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel

class MethodCallHandlerImpl(private val appierFlutter: AppierFlutter) : MethodChannel.MethodCallHandler {

  /**
   * The MethodChannel that will the communication between Flutter and native Android
   *
   * This local reference serves to register the plugin with the Flutter Engine and unregister it
   * when the Flutter Engine is detached from the Activity
   */
  private var channel: MethodChannel? = null

  /**
   * Registers this instance as a method call handler on the given `messenger`.
   *
   * Stops any previously started and unstopped calls.
   * This should be cleaned with [.stopListening] once the messenger is disposed of.
   */
  fun startListening(messenger: BinaryMessenger) {
    channel = MethodChannel(messenger, "appier_flutter")
    channel?.setMethodCallHandler(this)
  }

  /**
   * Clears this instance from listening to method calls.
   *
   * Does nothing if [.startListening] hasn't been called, or if we're already stopped.
   */
  fun stopListening() {
    channel?.setMethodCallHandler(null)
    channel = null
  }

  @Suppress("UNCHECKED_CAST")
  override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: MethodChannel.Result) {
    val arguments = call.arguments as? HashMap<String , Any?>
    if (arguments == null) {
      result.error("ILLEGAL_ARGUMENT", "${call.method}: arguments should be a hashmap", null)
      return
    }
    when (call.method) {
      "configure" -> appierFlutter.configure(arguments, result)
      "renewAppierId" -> appierFlutter.renewAppierId(arguments, result)
      "getAppierId" -> appierFlutter.getAppierId(arguments, result)
      "setUniversalLinkDomains" -> appierFlutter.setUniversalLinkDomains(result)
      "logEvent" -> appierFlutter.logEvent(arguments, result)
      "flush" -> appierFlutter.flush(arguments, result)
      "setUserId" -> appierFlutter.setUserId(arguments, result)
      "setName" -> appierFlutter.setName(arguments, result)
      "setFirstName" -> appierFlutter.setFirstName(arguments, result)
      "setLastName" -> appierFlutter.setLastName(arguments, result)
      "setCity" -> appierFlutter.setCity(arguments, result)
      "setEmail" -> appierFlutter.setEmail(arguments, result)
      "setPhoneNumber" -> appierFlutter.setPhoneNumber(arguments, result)
      "setDayOfBirth" -> appierFlutter.setDayOfBirth(arguments, result)
      "setMonthOfBirth" -> appierFlutter.setMonthOfBirth(arguments, result)
      "setYearOfBirth" -> appierFlutter.setYearOfBirth(arguments, result)
      "setCustomKey" -> appierFlutter.setCustomKey(arguments, result)
      "setAttributionWindow" -> appierFlutter.setAttributionWindow(arguments, result)
      "setClickAttributionWindow" -> appierFlutter.setClickAttributionWindow(arguments, result)
      "getRecommendation" -> appierFlutter.getRecommendation(arguments, result)
      "logRecommendationClicked" -> appierFlutter.logRecommendationClicked(arguments, result)
      "handleRemoteMessage" -> appierFlutter.handleRemoteMessage(arguments, result)
      "hideInAppCampaigns" -> appierFlutter.hideInAppCampaigns(arguments, result)
      else -> result.notImplemented()
    }
  }
}
